---
title: Building the base
description: Step-by-step guide to creating a mouse from plastic waste
---

import StepWithCarousel from '@site/src/components/StepWithCarousel';

[[INSERT VIDEO HERE]]

## Step 1: Assemble and customise the base structure

We'll start with assembling the base structure and making the required modifications to turn it into a sink.

<StepWithCarousel
  images={[
	{ src: '/img/step1/2_toptray.webp', caption: 'Adjusted layout of top tray walls on the floor' },
	{ src: '/img/step1/2_mark.webp', caption: 'Mark the holes for the new wall combination and child height' },
	{ src: '/img/step1/3_plastic_piece.webp', caption: 'Use provided plastic pieces to fix the top tray in the new holes' },
	{ src: '/img/step1/4_top_done.webp', caption: 'When done, top tray looks like this' },
	{ src: '/img/step1/6_trays.webp', caption: 'All three trays assembled' },
  ]}
>

  <p>
	* **1.1 Unpack**: Open the Ikea Nissafors box and follow the included manual to build the base structure. There are some changes you need to make in order to customise it into a sink that are explained in this page.
	* **1.2 Adjust height**: Position top tray at your child's height. The washbasin should be below their elbow height. In this heaight, see if you can use the existing holes of the top tray. We were able to make use of the existing holes as my son was sufficiently high. 
	* **1.3 Modify top tray combination**: Use the higher wall pieces from the bottom tray as the side and back walls for the washbasin (top tray). Keeping a lower front piece will allow easier access to the faucet.
	* **1.4 Mark location of additional holes to drill**: The new combination of the top tray walls requires at least 4 additional holes, if you make use of the existing holes. If not, you need to drill all 8 holes yourself. Mark the locations for the holes. If you're using existing holes, measure the distances of the new holes to the existing ones using a side piece of the tray.
	* **1.5 Drill the additional holes**: Only drill on the inside of metal frame (no need to drill all the way through). Use a 5.5mm bit (or use 5mm and expand the hole slightly) to be able to use the provided plastic pieces.
	* **1.6 Install the top tray**: Only install the sides, and not the central surface since we’ll insert the washbasin there. For existing holes, use the scres Ikea provided.
	* **1.7 Install the middle and bottom trays**: Given the customisation on the top tray, we used the remaining pieces on the bottom tray.

	⠀**Result**: The trolley is customized and ready for washbasin installation.
  </p>
</StepWithCarousel>


## Step 2: Prepare the washbasin

Now we'll convert the plastic tray into a washbasin.


<StepWithCarousel
  title="Step 2: Shape the Mold"
  images={[
    { src: '/img/step2/holes.jpg', caption: 'Drill at least 5 holes on each side of the washbasin.' },
    { src: '/img/step2/mark.jpg', caption: 'Offset slightly from the center to escape the center bumper' },
	{ src: '/img/step2/drill.jpg', caption: 'Drill matching the size of your screw' },
	{ src: '/img/step2/screw.jpg', caption: 'Screw the nut in place' },
	{ src: '/img/step2/glue.jpg', caption: 'Apply some hot glue' },
	{ src: '/img/step2/nut_inplace.jpg', caption: 'After glue is cold, remove the screw, and the nut would remain in place' },
  ]}
>
  <p>
    * **2.1 Drill drainage holes**: Create at least 5 holes on each side of the tray at the deepest edges to ensure complete water drainage. The modified tray should now resemble a washbasin and sit properly on the top tray of the frame.
	* **2.2 Drill pivot holes**: Locate the center of the plastic tray and drill holes slightly offset from center (to avoid the plastic bumper in the exact center). Ensure the offset is on the same side on both sides. Drill matching your screw diameter.
	* **2.4 Fix the nuts**:
		* Screw nuts onto bolts inside the washbasin holes
		* Apply hot glue around each nut to lock in position
		* Once glue dries, remove screws—nuts stay permanently fixed
  
  **Result**: Washbasin ready for installation with glued-in-place nuts.
  </p>
</StepWithCarousel>

## Step 3: Enabling pivoting motion of the washbasin


<StepWithCarousel
  title="Step 3: Assemble the Electronics"
  images={[
	{ src: '/img/step3/step1.jpg', caption: 'Mark drill point on the horizontal center of the top trays' },
	{ src: '/img/step3/step2.jpg', caption: 'Drill front hole' },
	{ src: '/img/step3/step3.jpg', caption: 'Measure the height of the front hole and mark a hole matching it at the horizantal center of the back.' },
	{ src: '/img/step3/step4.jpg', caption: 'After drilling the back hole, screw the washbasin through both holes' },
	{ src: '/img/step3/step5.jpg', caption: 'When done, the washbasin is installed and tiltable' },
  ]}
>
  <p>

	In the middle of the tray, we'll make a pivoting hole which will hold the washbasin. With that, the tray can be rotated to each side to enable the 2 mode design:
	* Tilted to **Left**: Clean water circulation for play (water recycles)
	* Tilted to **Right**: Dirty water disposal or for washing with soap (drains to waste bucket)

Here are the actions in this step: 
	* **3.1 Mark drill points**: Locate the horizontal center of the top tray's front and back edges.
	* **3.2 Drill front hole**: Drill through the front section at the marked center point as high as possible. This would maximize tilt range.
	* **3.3 Measure and match**: Measure the height of the front hole from the bottom of the metal piece.
	* **3.4 Drill back hole**: Using the same height measurement from the bottom of the metal piece at the back, drill the back hole to ensure the washbasin remains level when connected to the holes.
	* **3.5 Install**: Screw the washbasin to the top tray through both holes to enable left-right rotation.

	**Key point**: Higher hole placement = Greater tilt range for the wash person.

	**Result**: Sink structure and washbasin are ready. Now it's time to install the pump, filter, switchbox and the faucet.
  </p>
</StepWithCarousel>
